==> nextcloud-26.0.10.tgz: nextcloud/apps/federatedfilesharing/l10n/es.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "¿Deseas añadir el recurso compartido remoto {name} de {owner}@{remote}?",
    "Remote share" : "Recurso compartido remoto",
    "Remote share password" : "Contraseña del compartido remoto",
    "Cancel" : "Cancelar",
    "Add remote share" : "Añadir recurso compartido remoto",
    "Invalid Federated Cloud ID" : "ID de Nube Federada no válida",
    "Server to server sharing is not enabled on this server" : "Compartir entre servidores no está habilitado en este servidor",
    "Couldn't establish a federated share." : "No se puede añadir un compartido remoto",
    "Couldn't establish a federated share, maybe the password was wrong." : "No se pudo establecer un compartido remoto, puede que la contraseña fuera incorrecta.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Petición de recurso compartido federado enviada, recibirás una invitación. Comprueba tus notificaciones.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "No se ha podido establecer un compartido federado, parece ser que el servidor a federar es demasiado antiguo (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "No está permitido enviar compartidos de grupos federados desde este servidor.",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Fallo al compartir %1$s porque este objeto ya está compartido con el usuario %2$s",
    "Not allowed to create a federated share with the same user" : "No se permite crear un recurso compartido federado con el mismo usuario",
    "Federated shares require read permissions" : "Los recursos compartidos federados necesitan permiso de lectura",
    "File is already shared with %s" : "El archivo ya está siendo compartido con %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Compartir %1$s ha fallado, no se ha podido encontrar %2$s, quizás el servidor no se puede alcanzar ahora mismo o usa un certificado autofirmado.",
    "Could not find share" : "No se ha podido encontrar el compartido",
    "Federated sharing" : "Compartido federado",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Has recibido {share} como un recurso compartido remoto de {user} (en nombre de {behalf})",
    "You received {share} as a remote share from {user}" : "Has recibido {share} como un compartido remoto de {user}",
    "Accept" : "Aceptar",
    "Decline" : "Denegar",
    "Federated Cloud Sharing" : "Compartido en Cloud Federado",
    "Sharing" : "Compartir",
    "Federated file sharing" : "Compartir federado",
    "Provide federated file sharing across servers" : "Provee compartición federada de archivos entre servidores",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Ajusta cómo las personas pueden compartir entre servidores. Esto incluye también los recursos compartidos entre usuarios de este servidor si utilizan el uso compartido federado.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Permitir a los usuarios de este servidor compartir con usuarios de otros servidores (esta opción también permite acceso de WebDAV a los elementos públicos compartidos)",
    "Allow users on this server to receive shares from other servers" : "Permitir a los usuarios de este servidor recibir de usuarios de otros servidores",
    "Allow users on this server to send shares to groups on other servers" : "Permitir a los usuarios de este servidor enviar a grupos de otros servidores",
    "Allow users on this server to receive group shares from other servers" : "Permitir a los usuarios de este servidor recibir de grupos de otros servidores",
    "Search global and public address book for users" : "Buscar usuarios en libreta de direcciones global y pública",
    "Allow users to publish their data to a global and public address book" : "Permitir a los usuarios publicar su información en la libreta de direcciones global y pública",
    "Unable to update federated files sharing config" : "Incapaz de actualizar la configuración de la compartición federada de archivos",
    "Federated Cloud" : "Nube Federada",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Puedes compartir con cualquiera que use un servidor Nextcloud u otros servidores y servicios compatibles con Open Cloud Mesh (OCM). Simplemente, pon su ID de Nube Federada en el diálogo de compartir. Es algo como persona@nube.ejemplo.com",
    "Your Federated Cloud ID:" : "Tu ID de Nube Federada:",
    "Share it so your friends can share files with you:" : "Compártelo para que tus amigos puedan compartir archivos contigo:",
    "Facebook" : "Facebook",
    "Twitter" : "Twitter",
    "Diaspora" : "Diaspora",
    "Add to your website" : "Añadir a su sitio web",
    "Share with me via Nextcloud" : "Compartirlo conmigo vía Nextcloud",
    "HTML Code:" : "Código HTML:",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Comparte conmigo a través de mi #Nextcloud Federated Cloud ID, ver {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Compartirlo conmigo a través de mi ID de Nube Federada #Nextcloud",
    "Cloud ID copied to the clipboard" : "ID de nube copiado al portapapeles",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Clipboard is not available" : "El portapapeles no está disponible",
    "Copied!" : "¡Copiado!"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-28.0.3.tgz: nextcloud/apps/federatedfilesharing/l10n/es.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "¿Deseas añadir el recurso compartido remoto {name} de {owner}@{remote}?",
    "Remote share" : "Recurso compartido remoto",
    "Remote share password" : "Contraseña del compartido remoto",
    "Cancel" : "Cancelar",
    "Add remote share" : "Añadir recurso compartido remoto",
    "Invalid Federated Cloud ID" : "ID de Nube Federada no válida",
    "Server to server sharing is not enabled on this server" : "Compartir entre servidores no está habilitado en este servidor",
    "Couldn't establish a federated share." : "No se puede añadir un compartido remoto",
    "Couldn't establish a federated share, maybe the password was wrong." : "No se pudo establecer un compartido remoto, puede que la contraseña fuera incorrecta.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Petición de recurso compartido federado enviada, recibirá una invitación. Compruebe sus notificaciones.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "No se ha podido establecer un recurso compartido federado, parece ser que el servidor con el que se intenta federar es demasiado antiguo (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "No está permitido enviar recursos compartidos federados de grupos desde este servidor.",
    "Federated shares require read permissions" : "Los recursos compartidos federados necesitan permiso de lectura",
    "File is already shared with %s" : "El archivo ya está siendo compartido con %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Compartir %1$s ha fallado, no se ha podido encontrar %2$s, quizás el servidor no se puede alcanzar ahora mismo o usa un certificado autofirmado.",
    "Could not find share" : "No se ha podido encontrar el compartido",
    "Federated sharing" : "Compartido federado",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Has recibido {share} como un recurso compartido remoto de {user} (en nombre de {behalf})",
    "You received {share} as a remote share from {user}" : "Has recibido {share} como un compartido remoto de {user}",
    "Accept" : "Aceptar",
    "Decline" : "Denegar",
    "Federated Cloud Sharing" : "Compartido en Nube Federada",
    "Sharing" : "Compartir",
    "Federated file sharing" : "Compartir federado",
    "Provide federated file sharing across servers" : "Provee compartición federada de archivos entre servidores",
    "Unable to update federated files sharing config" : "Incapaz de actualizar la configuración de la compartición federada de archivos",
    "Federated Cloud" : "Nube Federada",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "¡Puede compartir con cualquier persona que use un servidor Nextcloud u otros servidores y servicios compatibles con Open Cloud Mesh (OCM)!. Solo coloque el ID de Nube Federada de esta(s) persona(s) en el diálogo de compartir. Se verán así: persona@nube.ejemplo.com",
    "Your Federated Cloud ID:" : "Tu ID de Nube Federada:",
    "Share it so your friends can share files with you:" : "Compártelo para que tus amigos puedan compartir archivos contigo:",
    "Facebook" : "Facebook",
    "Twitter" : "Twitter",
    "Diaspora" : "Diaspora",
    "Add to your website" : "Añadir a su sitio web",
    "Share with me via Nextcloud" : "Compartirlo conmigo vía Nextcloud",
    "HTML Code:" : "Código HTML:",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Comparte conmigo a través de mi ID de Nube Federada #Nextcloud, ve {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Compartirlo conmigo a través de mi ID de Nube Federada #Nextcloud",
    "Cloud ID copied to the clipboard" : "ID de nube copiado al portapapeles",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Clipboard is not available" : "El portapapeles no está disponible",
    "Copied!" : "¡Copiado!",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Fallo al compartir %1$s porque este objeto ya está compartido con el usuario %2$s",
    "Not allowed to create a federated share with the same user" : "No se permite crear un recurso compartido federado con el mismo usuario",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Ajuste cómo las personas pueden compartir entre servidores. Esto incluye también los recursos compartidos entre usuarios de este servidor si utilizan recursos compartidos federados.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Permitir a los usuarios de este servidor compartir con usuarios de otros servidores (esta opción también permite acceso de WebDAV a los elementos públicos compartidos)",
    "Allow users on this server to receive shares from other servers" : "Permitir a los usuarios de este servidor recibir de usuarios de otros servidores",
    "Allow users on this server to send shares to groups on other servers" : "Permitir a los usuarios de este servidor enviar a grupos de otros servidores",
    "Allow users on this server to receive group shares from other servers" : "Permitir a los usuarios de este servidor recibir de grupos de otros servidores",
    "Search global and public address book for users" : "Buscar usuarios en libreta de direcciones global y pública",
    "Allow users to publish their data to a global and public address book" : "Permitir a los usuarios publicar su información en la libreta de direcciones global y pública"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
